Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMadhura Jayaratne <madhura.cj@gmail.com>2015-04-03 13:02:36 +0300
committerMadhura Jayaratne <madhura.cj@gmail.com>2015-04-03 13:02:36 +0300
commit8b1cbaf988ebcc546611b085d91d399ad0f2f195 (patch)
tree52dbe816ec3512494e3e0697dd3aa2d8388a69e5 /chk_rel.php
parent927b95bc233f5e485f500b35f570bd4a2508cda8 (diff)
rfe #1635 Have ZeroConf create phpmyadmin DB if possible
Signed-off-by: Madhura Jayaratne <madhura.cj@gmail.com>
Diffstat (limited to 'chk_rel.php')
-rw-r--r--chk_rel.php9
1 files changed, 8 insertions, 1 deletions
diff --git a/chk_rel.php b/chk_rel.php
index fcf0c66756..e62288401e 100644
--- a/chk_rel.php
+++ b/chk_rel.php
@@ -8,8 +8,15 @@
require_once 'libraries/common.inc.php';
// If request for creating all PMA tables.
if (isset($_REQUEST['create_pmadb'])) {
+ if (PMA_createPMADatabase()) {
+ PMA_fixPMATables('phpmyadmin');
+ }
+}
+
+// If request for creating all PMA tables.
+if (isset($_REQUEST['fixall_pmadb'])) {
PMA_fixPMATables($GLOBALS['db']);
}
@@ -8,8 +8,15 @@
require_once 'libraries/common.inc.php';
-// If request for creating all PMA tables.
+// If request for creating the pmadb
if (isset($_REQUEST['create_pmadb'])) {